pub struct ChunkRequest {
pub status: ChunkStatus,
pub positions: Vec<ChunkPos>,
pub ticket_kind: ChunkTicketKind,
}Expand description
Request for a set of chunks at a minimum generation status.
Fields
status: ChunkStatusMinimum chunk status required before the request is ready.
positions: Vec<ChunkPos>Chunk positions requested.
ticket_kind: ChunkTicketKindTicket owner category.